import { forwardRef, memo, useImperativeHandle, useState } from 'react'
import { cloneDeep } from 'lodash-es'
import { getTenantApply, ITenantApplyInfo } from '@/api/services/riskcontrol/declare'
import { orderStateMap } from './constants/orderState'

export interface FormParseRef {}

interface FormParseProps {
  declFormData: Nullable<API.OpenDeclFormResult>
  formData: Record<string, any>
  formRule?: any
  disabled?: boolean
  state?: string
  expiry?: string
  isExpiry?: boolean
  className?: string
}

const checkStateMap = {
  PASSED: '通过',
  REJECTED: '拒绝',
  TO_RECT: '整改'
}

const FormParse = memo(
  forwardRef<FormParseRef, FormParseProps>(
    ({ declFormData, formData, formRule, disabled, state, expiry, isExpiry }, ref) => {
      console.log(formData)
      console.log(formRule)
      console.log(disabled)
      // 对外暴露方法
      useImperativeHandle(ref, () => {
        return {}
      })

      const formItemsCopy = cloneDeep(declFormData?.formItems)
      console.log(formItemsCopy)

      const [showViewPayInfoDialog, setShowViewPayInfoDialog] = useState(false)
      console.log(showViewPayInfoDialog)
      const [payInfo, setPayInfo] = useState<Partial<API.PayDetail>>({
        reqSn: '',
        amount: '',
        orderState: '',
        paymentTime: '',
        issueTime: '',
        expireTime: '',
        payType: ''
      })
      console.log(payInfo)
      const viewPayInfoDialog = () => {
        setPayInfo(declFormData!.payDetail)
        setShowViewPayInfoDialog(true)
      }

      const [tennantInfo, setTennantInfo] = useState<Partial<ITenantApplyInfo>>()
      console.log(tennantInfo)
      const [showAccountDialog, setShowAccountDialog] = useState(false)
      console.log(showAccountDialog)
      const viewAccountInfoDialog = async () => {
        const res = await getTenantApply({
          declId: declFormData!.declarationId,
          regCode: declFormData!.regCode
        })
        if (res?.code === '2000') {
          setTennantInfo(res.data)
          setShowAccountDialog(true)
        }
      }

      return (
        <div>
          {state && (
            <div className='text-[14px] pl-[12px] mb-[8px] text-text-secondary f-b-c'>
              <div>
                <span>
                  {typeof isExpiry === 'boolean'
                    ? isExpiry
                      ? '已结束'
                      : `有效期至：${expiry}`
                    : ''}
                </span>
                <span className='ml-[20px]'>填报状态：{state}</span>
                {declFormData?.declarationState === 'ROLLBACK' && (
                  <span className='ml-[20px]'>退回原因：{declFormData?.rollbackRemark}</span>
                )}
              </div>
              <div className='flex'>
                {declFormData?.payDetail?.bizPayType === 'HYBRID_PAID' && (
                  <div>
                    <span>
                      准入管理费支付状态：
                      {
                        orderStateMap[
                          declFormData?.payDetail?.orderState as keyof typeof orderStateMap
                        ]
                      }
                    </span>
                    <span
                      className='text-primary ml-[6px] cursor-pointer'
                      onClick={viewPayInfoDialog}>
                      详情
                    </span>
                  </div>
                )}
                {declFormData?.isTenantApplied && (
                  <div className='ml-[16px]'>
                    <span>登录账号：</span>
                    <span
                      className='text-primary ml-[6px] cursor-pointer'
                      onClick={viewAccountInfoDialog}>
                      查看
                    </span>
                  </div>
                )}
              </div>
            </div>
          )}
          <div className='mb-[12px] text-[14px] text-text-secondary bg-[#F6FAFF] rounded-[4px] px-[12px] py-[8px]'>
            <span>
              企业审核结果：
              {declFormData?.checkState
                ? checkStateMap[declFormData.checkState as keyof typeof checkStateMap]
                : '-'}
            </span>
            <span className='ml-20'>审核意见：{declFormData?.checkMsg || '-'}</span>
            <span className='ml-20 break-all'>原因说明：{declFormData?.remarks || '-'}</span>
          </div>
        </div>
      )
    }
  )
)

export default FormParse
